package com.coydone.test;


import com.coydone.entity.Student;
import com.coydone.entity.StudentCondition;
import com.coydone.mapper.StudentMapper;
import com.coydone.utils.MyBatisUtil;
import com.coydone.utils.PageUtils;
import org.apache.ibatis.session.SqlSession;
import org.junit.Test;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

public class StudentTest {
    SqlSession sqlSession = MyBatisUtil.getSession();
    StudentMapper studentMapper = sqlSession.getMapper(StudentMapper.class);
    @Test
    public void findAll(){

        List<Student> students = studentMapper.findAll();
        for (Student student : students) {
            System.out.println(student);
        }
    }

    @Test
    public void addStudent(){
        Scanner input=new Scanner(System.in);
        System.out.println("请输入学号:");
        int xh=input.nextInt();
        System.out.println("请输入姓名:");
        String name=input.next();
        System.out.println("请输入年龄:");
        int age =input.nextInt();
        System.out.println("请输入性别:");
        String sex=input.next();
        System.out.println("请输入生日:");
        String birthday =input.next();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        Date date = null;
        try {
            date = sdf.parse(birthday);
        } catch (ParseException e) {
            e.printStackTrace();
        }

        System.out.println("请输入状态:");
        int state=input.nextInt();
        System.out.println("请输入地址:");
        String address=input.next();
        System.out.println("请输入gid:");
        int gid=input.nextInt();

        Student student = new Student(xh,name,age,sex,date,state,address,gid);
        int rows = studentMapper.addStudent(student);
        sqlSession.commit();
        if(rows>0)
            System.out.println("添加成功");
        else
            System.out.println("添加失败");
    }

    @Test
    public void updateStudent(){
        Scanner input=new Scanner(System.in);
        System.out.println("请输入要修改的学号:");
        int xh=input.nextInt();
        System.out.println("请输入修改的姓名:");
        String name=input.next();
        System.out.println("请输入修改的地址:");
        String address=input.next();


        Student student = studentMapper.findById(xh);

        student.setName(name);
        student.setAddress(address);

        int rows = studentMapper.updateStudent(student);
        sqlSession.commit();
        if(rows>0)
            System.out.println("修改成功");
        else
            System.out.println("修改失败");
    }

    @Test
    public void deleteStudent(){
        Scanner input=new Scanner(System.in);
        System.out.println("请输入要删除的学号:");
        int xh=input.nextInt();

        int rows = studentMapper.deleteStudent(xh);
        sqlSession.commit();
        if(rows>0)
            System.out.println("删除成功");
        else
            System.out.println("删除失败");
    }

    @Test
    public void findById(){
        Scanner input=new Scanner(System.in);
        System.out.println("请输入要查询的学号:");
        int xh =input.nextInt();

        Student student = studentMapper.findById(xh);
        System.out.println(student);
    }

    @Test
    //条件查询
    public void findByConditon(){
        Scanner input=new Scanner(System.in);
        System.out.println("请输入要查询的姓名:");
        String name =input.nextLine();

        System.out.println("请输入起始年龄:");
        String startAge =input.nextLine();

        System.out.println("请输入结束年龄:");
        String endAge =input.nextLine();

        System.out.println("请输入地址:");
        String address =input.nextLine();

        StudentCondition condition = new StudentCondition();

        if (name!=null&&!name.equals("")){
            condition.setName(name);
        }
        if (!startAge.equals("")){
            condition.setStartAge(Integer.parseInt(startAge));
        }
        if (!endAge.equals("")){
            condition.setEndAge(Integer.parseInt(endAge));
        }

        if (!address.equals("")){
            condition.setAddress(address);
        }


        List<Student> students = studentMapper.findStudentByCondition(condition);
        for (Student student : students) {
            System.out.println(student);
        }
        //关闭sqlSession
        MyBatisUtil.closeSession();
    }

    @Test
    //条件查询总记录数
    public void findCounts(){
        Scanner input=new Scanner(System.in);
        System.out.println("请输入要查询的姓名:");
        String name =input.nextLine();

        System.out.println("请输入起始年龄:");
        String startAge =input.nextLine();

        System.out.println("请输入结束年龄:");
        String endAge =input.nextLine();

        System.out.println("请输入地址:");
        String address =input.nextLine();

        StudentCondition condition = new StudentCondition();

        if (name!=null&&!name.equals("")){
            condition.setName(name);
        }
        if (!startAge.equals("")){
            condition.setStartAge(Integer.parseInt(startAge));
        }
        if (!endAge.equals("")){
            condition.setEndAge(Integer.parseInt(endAge));
        }

        if (!address.equals("")){
            condition.setAddress(address);
        }

        int counts = studentMapper.findCounts(condition);
        System.out.println(counts);

        //关闭sqlSession
        MyBatisUtil.closeSession();
    }

    @Test
    //多条件分页查询
    public void findAllByLimit(){
        Scanner input=new Scanner(System.in);
        System.out.println("请输入要查询的姓名:");
        String name =input.nextLine();

        System.out.println("请输入起始年龄:");
        String startAge =input.nextLine();

        System.out.println("请输入结束年龄:");
        String endAge =input.nextLine();

        System.out.println("请输入地址:");
        String address =input.nextLine();

        PageUtils pageUtils = new PageUtils();
        //设置当前页
        pageUtils.setCurrentPage(1);
        //设置每页显示的总条数
        pageUtils.setPageSize(5);

        StudentCondition condition = new StudentCondition();
        int counts = studentMapper.findCounts(condition);
        pageUtils.setTotalCount(counts);

        Map<String , Object> map = new HashMap<>();

        if (name!=null&&!name.equals("")){
            map.put("name", name);
        }
        if (!startAge.equals("")){
            map.put("startAge", startAge);
        }
        if (!endAge.equals("")){
            map.put("endAge", endAge);
        }

        if (!address.equals("")){
            map.put("address", address);
        }

        map.put("startIndex", pageUtils.getStartIndex());
        map.put("pageSize", pageUtils.getPageSize());

        List<Student> students = studentMapper.findAllByLimit(map);
        for (Student student : students) {
            System.out.println(student);
        }
        System.out.println("当前第"+pageUtils.getCurrentPage()+"页，共"+counts+"条");
        //关闭sqlSession
        MyBatisUtil.closeSession();
    }

    //查询所有学生及所在的年级
    @Test
    public void findAllStudentAndGrade(){
        List<Student> studentAndGrade = studentMapper.findAllStudentAndGrade();
        for (Student student : studentAndGrade) {
            System.out.println(student+student.getGname());
        }
    }

    //查询所有学生及所在的年级
    @Test
    public void findAllStudentAndGrade2(){
        List<Student> allStudentAndGrade2 = studentMapper.findAllStudentAndGrade2();
        for (Student student : allStudentAndGrade2) {
            System.out.println(student+student.getGrade().getGname());
        }
    }

}

